┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinviewactionhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinviewactionhandler.h')
-rw-r--r--src/dolphinviewactionhandler.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/dolphinviewactionhandler.h b/src/dolphinviewactionhandler.h
index 5193da719..4186a479f 100644
--- a/src/dolphinviewactionhandler.h
+++ b/src/dolphinviewactionhandler.h
@@ -23,7 +23,10 @@
#include "dolphinview.h"
#include "libdolphin_export.h"
+#include <kactionmenu.h>
+#include <kselectaction.h>
#include <QtCore/QObject>
+
class KToggleAction;
class QAction;
class QActionGroup;
@@ -217,10 +220,10 @@ private:
*/
void createActions();
/**
* Creates an action group with all the "show additional information" actions in it.
* Helper method for createActions();
*/
- QActionGroup* createAdditionalInformationActionGroup();
+ KActionMenu* createAdditionalInformationActionMenu();
/**
* Creates an action group with all the "sort by" actions in it.
@@ -217,10 +220,10 @@ private:
void createActions();
/**
- * Creates an action group with all the "show additional information" actions in it.
+ * Creates an action menu with all the "show additional information" actions in it.
* Helper method for createActions();
*/